{% load wiki_tags i18n cache sekizai_tags %}

{% addtoblock "js" %}        
  <script type="text/javascript" src="{{ STATIC_URL }}wiki/js/article.js"></script>
{% endaddtoblock %}

<div class="wiki-article">
  {% if not preview %}
    {% if article.current_revision %}
      {{ article.get_cached_content }}
    {% endif %}
  {% else %}
    {{ content|default:"" }}
  {% endif %}
</div>

{% for plugin in plugins %}
  {% if plugin.RenderMedia.css %}
    {% addtoblock "css" %}
      {% for media, url in plugin.RenderMedia.css.items %}
        <link rel="stylesheet" href="{{ STATIC_URL }}{{ url }}" />
      {% endfor %}
    {% endaddtoblock %}
  {% endif %}
  {% if plugin.RenderMedia.js %}
    {% addtoblock "js" %}        
      {% for url in plugin.RenderMedia.js %}
        <script type="text/javascript" src="{{ STATIC_URL }}{{ url }}"></script>
      {% endfor %}
    {% endaddtoblock %}
  {% endif %}
{% endfor %}

