//
// Pagination (multiple pages)
// --------------------------------------------------
.pagination {
  display: inline-block;
  padding-left: 0;
  margin: @line-height-computed 0;
  border-radius: @border-radius-base;
  
  > li {
    display: inline; // Remove list-style and block-level defaults
    > a,
    > span {
      float: left; // Collapse white-space
      padding: 4px 12px;
      line-height: @line-height-base;
      text-decoration: none;
      background-color: @pagination-bg;
      border: 1px solid @pagination-border;
      border-left-width: 0;
    }
    &:first-child {
      > a,
      > span {
        border-left-width: 1px;
        .border-left-radius(@border-radius-base);
      }
    }
    &:last-child {
      > a,
      > span {
        .border-right-radius(@border-radius-base);
      }
    }
  }
  
  > li > a:hover,
  > li > a:focus,
  > .active > a,
  > .active > span {
    background-color: @pagination-active-bg;
  }
  > .active > a,
  > .active > span {
    color: @pagination-active-color;
    cursor: default;
  }
  
  > .disabled {
    > span,
    > a,
    > a:hover,
    > a:focus {
      color: @pagination-disabled-color;
      background-color: @pagination-bg;
      cursor: not-allowed;
    }
  }
}

// Sizing
// --------------------------------------------------

// Large
.pagination-large {
  > li {
    > a,
    > span {
      padding: @padding-large-vertical @padding-large-horizontal;
      font-size: @font-size-large;
    }
    &:first-child {
      > a,
      > span {
        .border-left-radius(@border-radius-large);
      }
    }
    &:last-child {
      > a,
      > span {
        .border-right-radius(@border-radius-large);
      }
    }
  }
}

// Small
.pagination-small {
  > li {
    > a,
    > span {
      padding: @padding-small-vertical @padding-small-horizontal;
      font-size: @font-size-small;
    }
    &:first-child {
      > a,
      > span {
        .border-left-radius(@border-radius-small);
      }
    }
    &:last-child {
      > a,
      > span {
        .border-right-radius(@border-radius-small);
      }
    }
  }
}
