//
// Thumbnails
// --------------------------------------------------


// Base classes
// For thumbnail block-level composite components and simple image styles

// The actual thumbnailed element
// Can be `a`, `div`, or `img`
.thumbnail,
.img-thumbnail {
  padding: 4px;
  line-height: @line-height-base;
  background-color: @thumbnail-bg;
  border: 1px solid @thumbnail-border;
  border-radius: @thumbnail-border-radius;
  .transition(all .2s ease-in-out);
}
.thumbnail {
  display: block;
}
.thumbnail > img,
.img-thumbnail {
  .img-responsive();
}

// Add a hover state for linked versions only
a.thumbnail:hover,
a.thumbnail:focus {
  border-color: @link-color;
}

// Images and captions
.thumbnail > img {
  margin-left: auto;
  margin-right: auto;
}
.thumbnail .caption {
  padding: 9px;
  color: @thumbnail-caption-color;
}
