//
// Accordion
// --------------------------------------------------


// Parent container
.accordion {
  margin-bottom: @line-height-computed;
}

// Group == heading + body
.accordion-group {
  margin-bottom: 2px;
  border: 1px solid @accordion-border-color;
  border-radius: @border-radius-base;
}
.accordion-heading {
  border-bottom: 0;

  .accordion-toggle {
    display: block;
    padding: 8px 15px;
    cursor: pointer;
  }
}

// Inner needs the styles because you can't animate properly with any styles on the element
.accordion-inner {
  padding: 9px 15px;
  border-top: 1px solid @accordion-border-color;
}
