//
// Jumbotron
// --------------------------------------------------


.jumbotron {
  padding: 30px;
  margin-bottom: 30px;
  font-size: (@font-size-base * 1.5);
  font-weight: 200;
  line-height: (@line-height-base * 1.5);
  color: @jumbotron-lead-color;
  background-color: @jumbotron-bg;
  h1 {
    line-height: 1;
    color: @jumbotron-heading-color;
  }
  p {
    line-height: 1.4;
  }

  @media screen and (min-width: @screen-tablet) {
    padding: 50px 60px;
    border-radius: @border-radius-large; // Only round corners at higher resolutions
    h1 {
      font-size: (@font-size-base * 4.5);
    }
  }
}
