/*!
 * This is django-wiki's LESS rules built on top of
 * Bootstrap. Please do not modify the original Bootstrap
 * files as we try to maintain a simple and clean copy of
 * Bootstrap!!
 */
 
 // CSS Reset
@import "../bootstrap.less";

.wiki-article .thumbnail
{
    clear: both;
    margin-bottom: 15px;
    margin-left: 10px;
    margin-right: 10px;
}


/* WIKI ARTICLE FORM ELEMENTS */
#div_id_title .asteriskField{display:none}
#id_title {
    font-size: 20px;
    height: 40px;
    padding: 6px;
    display: block;
    width: 98%;
}
#id_summary {width: 98%; padding: 6px;}
#id_content {width: 100%; padding: 6px;}

h1#article-title {font-size: 2.5em; margin-top: 0px;}

label { font-size: 16px; font-weight: normal; color: #777;}

.controls ul
{
  margin-left: 0;
  list-style: none;
}

#attachment_form #id_description
{ width: 95% }

#wiki-edit-sidebar .accordion {margin-bottom: 5px;}

.wiki-article div.toc,
.wiki-article div.article-list {
    max-width: 340px;
    clear: left;
}

.wiki-article div.toc ul,
.wiki-article div.article-list ul {
    .list-unstyled;
}

.wiki-article div.toc > ul,
.wiki-article div.article-list > ul {
    .border-radius(5px);
    background-color: #f6f6f6;
    padding-top: 5px;
}

.wiki-article div.toc ul li ul li,
.wiki-article div.article-list ul li ul li {
    padding-left: 10px;
}
.wiki-article div.toc ul li a,
.wiki-article div.article-list ul li a {
    padding: 5px 10px;
    display: block;
    border-bottom: 1px solid #DDD;
}

.wiki-article div.toc ul li:last-child,
.wiki-article div.article-list ul li:last-child {
    margin-bottom: 7px;
}

.wiki-article div.toc .toctitle
{
    .dropdown-header;
}

.wiki-article a.linknotfound {color: #C87;}

.wiki-article pre {
  max-width: 700px;
}

.wiki-article table
{
    .table;
    .table-bordered;
}

.wiki-article h1,
.wiki-article h2,
.wiki-article h3,
.wiki-article h4,
.wiki-article h5,
.wiki-article h6
{
    overflow: hidden;
    margin-right: 5px;
}

.wiki-article h1
{
    font-size: @font-size-base * 2;
    .page-header;
}

.wiki-article h2
{
    font-size: @font-size-base * 1.75;
    .page-header;
    margin-bottom: 20px;
    padding-bottom: 0px;
}

.wiki-article h3
{
    font-size: @font-size-base * 1.50;
    margin: 15px 0 10px;
    line-height: 30px;
}

.wiki-article h4
{
    font-size: @font-size-base * 1.25;
}

.wiki-article h5,
.wiki-article h6
{
    font-size: @font-size-base;
}

.wiki-article blockquote p,
.wiki-article blockquote
{
    font-size: @font-size-base;
}


input[type=file] {float: none; width: auto;}
.asteriskField { font-size: 20px; margin-left: 5px;}

.notification-li .since {
  font-size: 80%;
  color: #CCC;
}

.directory-toolbar .filter-clear { margin-right: 10px; position: relative; top: 5px; }

.accordion-heading h3 {margin: 0;}

.breadcrumb .icon-bar {
    display: block;
    width: 18px;
    height: 2px;
    background-color: rgb(245, 245, 245);
    border-radius: 1px 1px 1px 1px;
    box-shadow: 0px 1px 0px rgba(0, 0, 0, 0.25);
    margin-top: 3px;
}
.breadcrumb .icon-bar:first-child{margin-top: 0;}

#article-menu
{
  border-bottom: 1px solid #EEE;
  padding-bottom: 0px;
  margin-bottom: 20px;
}

#article-container
{
  margin-top: 20px;
}

#wiki-footer
{
  padding: 30px 0;
  clear: both;
}

.wiki-modal .modal-body iframe
{
    width: 100%;
    min-height: 400px;
    height: 100%;
    border: 0;
}

// Resizable modals
.ui-resizable-s {
  bottom: 0;
}
.ui-resizable-e {
  right: 0;
}
.ui-resizable {
  position: fixed !important;
}

@media print
{
    .navbar,
    .nav-tabs li a,
    #article-breadcrumbs
    {display: none;}
    
    #article-menu li
    {
      display: none;
    }
    
    #article-title-li
    {
      display: block !important;
    }
}


/******************************
 FORMS - horizontal and vertical
*******************************/

/* Special form class that just has 100% width elements */
.wiki-form-block input[type='text'],
.wiki-form-block select

{
    display: block;
    width: auto;
    .form-control;
}

/* General styling, any kind of form input */
.wiki-control input[type=text],
.wiki-control input[type=password]
{
    display: inline-block;
    height: @input-height-base; // Make inputs at least the height of their button counterpart (base line-height + padding + border)
    padding: @padding-base-vertical @padding-base-horizontal;
    font-size: @font-size-base;
    line-height: @line-height-base;
    color: @gray;
    vertical-align: middle;
    width: 280px;
    display: inline-block;
}

.form-horizontal .wiki-control input[type='text'],
.form-horizontal .wiki-control input[type='password'],
.form-horizontal .wiki-control select,
.form-horizontal .wiki-control textarea
{
    .form-control;
    width: 280px;
    display: inline-block;
}

/* other fields */
.form-horizontal .wiki-control input[type=text],
.form-horizontal .wiki-control input[type=password]
{
    width: 280px;
    display: inline-block;
}

.form-horizontal .wiki-control .input-group
{
    width: 280px;
    display: inline-table;
}

.form-vertical .wiki-control textarea,
.form-horizontal .wiki-control textarea
{
    height: 200px;
}

.form-vertical .wiki-control input[type='text'],
.form-vertical .wiki-control select,
.form-vertical .wiki-control textarea
{
    .form-control;
    width: 95%; /* make room for an asterix */
    display: inline-block;
}

/* Reset column grid layout for vertical forms */
.form-vertical .wiki-control,
.form-vertical .wiki-label
{
    display: block;
    float: none;
    padding: 0; margin: 0;
    width: 100%;
}

.form-actions {
    .make-row();
    padding: 19px 15px 20px;
    padding-left: 0;
    margin-top: 20px;
    margin-bottom: 20px;
    background-color: rgb(245, 245, 245);
    border-top: 1px solid rgb(229, 229, 229);
    float: none;
}

// Assuming it's a nested icon
.accordion-heading .icon
{
    color: #444;
    font-size: 75%;
}

/******************************
 RESPONSIVE STUFF
*******************************/

.wiki-modal .modal-content { width: 100%; }

@media (min-width: 980px) {
    .wiki-modal .modal-dialog
    {
        width: 80%;
        margin-left: -40%;
    }
}
@media (max-width: 979px) {
    .wiki-modal .modal-dialog
    {
        width: 90%;
        margin-left: -45%;
    }
}
@media (max-width: 767px) {
    .wiki-modal .modal-dialog
    {
        width: 90%;
        margin-left: 0;
    }
}
@media screen and (min-width: @grid-float-breakpoint) {
    .pull-right-block-on-responsive {
        .pull-right;
    }
    #wiki-search-form {
        width: 140px;
    }
}

/******************************
 ICONS
*******************************/

@import "../../../font-awesome/less/font-awesome.less";

/******************************
 CODEHILITE / PYGMENTS
*******************************/

@import "codehilite.less";

/******************************
 TWITTER TYPEAHEAD
*******************************/

@import "typeahead.less";

