//
// Scaffolding
// --------------------------------------------------


// Reset the box-sizing
// -------------------------

* {
  .box-sizing(border-box);
}


// Body reset
// -------------------------

html {
  font-size: 62.5%;
  -webkit-tap-highlight-color: rgba(0,0,0,0);
}

body {
  font-family: @font-family-base;
  font-size: @font-size-base;
  line-height: @line-height-base;
  color: @text-color;
  background-color: @body-bg;
}

// Reset fonts for relevant elements
input,
button,
select,
textarea {
  font-family: inherit;
  font-size: inherit;
  line-height: inherit;
}


// Links
// -------------------------

a {
  color: @link-color;
  text-decoration: none;
}
a:hover,
a:focus {
  color: @link-hover-color;
  text-decoration: underline;
}
a:focus {
  .tab-focus();
}


// Images
// -------------------------

img {
  vertical-align: middle;
}

// Responsive images (ensure images don't scale beyond their parents)
.img-responsive {
  display: inline-block;
  max-width: 100%; // Part 1: Set a maximum relative to the parent
  height: auto; // Part 2: Scale the height according to the width, otherwise you get stretching
}

// Rounded corners
.img-rounded {
  border-radius: @border-radius-large;
}

// Image thumbnails
// See thumbnails.less for `.img-thumbnail`

// Perfect circle
.img-circle {
  border-radius: 500px; // crank the border-radius so it works with most reasonably sized images
}


// Horizontal rules
// -------------------------

hr {
  margin-top:    @line-height-computed;
  margin-bottom: @line-height-computed;
  border: 0;
  border-top: 1px solid @hr-border;
}

