#div_id_title .asteriskField{display:none}
#id_title {font-size: 20px; height: 30px; padding: 6px; width: 98%;}
#id_summary {width: 98%; padding: 6px;}

h1#article-title {font-size: 2em; margin-top: -5px;}

#article_edit_form label {max-width: 100px;}
#article_edit_form .controls {margin-left: 120px;}

.form-horizontal label { font-size: 16px; font-weight: normal; color: #777;}

.settings-form label {min-width: 250px; font-size: inherit; font-weight: normal;}
.settings-form .controls {margin-left: 270px;}
.settings-form select {}
.settings-form .form-actions { padding-left: 270px; }

#attachment_form #id_description
{ width: 95% }

#edit_sidebar .accordion {margin-bottom: 5px;}

.wiki-article div.toc,
.wiki-article div.article-list {
  margin: 10px 0;
  background: #f9f9f9;
  padding: 10px;
  width: 300px;
  border: 1px solid #CCC;
}
      
.wiki-article a.linknotfound {color: #C87;}

.wiki-article pre {
  max-width: 700px;
}

input[type=file] {float: none; width: auto;}
.asteriskField { font-size: 20px; margin-left: 5px;}

.notification-list .since {
  font-size: 80%;
  color: #CCC;
}

.directory-toolbar .filter-clear { margin-right: 10px; position: relative; top: 5px; }

.accordion-heading h3 {margin: 0;}

.breadcrumb .icon-bar {
    display: block;
    width: 18px;
    height: 2px;
    background-color: rgb(245, 245, 245);
    border-radius: 1px 1px 1px 1px;
    box-shadow: 0px 1px 0px rgba(0, 0, 0, 0.25);
    margin-top: 3px;
}
.breadcrumb .icon-bar:first-child{margin-top: 0;}

#navbar_wiki_search input.search-query {width: 80px;}

#article-menu
{
  border-bottom: 1px solid #EEE;
}

#article-container
{
  margin-top: 20px;
}

#wiki-footer
{
  padding: 30px 0;
  clear: both;
}
